@@ -15,7 +15,7 @@
 #endif /* __cplusplus */
 
 /* the installation location prefix from configure */
-#define wxINSTALL_PREFIX "C:/src/osgeo4w/src/wxwidgets/osgeo4w/install"
+#define wxINSTALL_PREFIX "D:/src/osgeo4w/src/wxwidgets/osgeo4w/install"
 
 /* Define if ssize_t type is available.  */
 /* #undef HAVE_SSIZE_T */
@@ -335,9 +335,9 @@
 #define wxUSE_WEBVIEW_EDGE_STATIC 0
 
 #if (defined(__WXGTK__) && !defined(__WXGTK3__)) || defined(__WXOSX__)
-#define wxUSE_WEBVIEW_WEBKIT 1
+#define wxUSE_WEBVIEW_WEBKIT 0
 #else
-#define wxUSE_WEBVIEW_WEBKIT 1
+#define wxUSE_WEBVIEW_WEBKIT 0
 #endif
 
 #if defined(__WXGTK3__)
